@@ -1,6 +1,8 @@
 import json
 from re import match
 from functools import reduce
+from typing import Any, Dict, Optional
+
 from samtranslator.model import PropertyType, Resource
 from samtranslator.model.exceptions import InvalidResourceException
 from samtranslator.model.types import is_type, one_of, is_str, list_of
@@ -24,6 +26,7 @@ class ApiGatewayRestApi(Resource):
         "BinaryMediaTypes": PropertyType(False, is_type(list)),
         "MinimumCompressionSize": PropertyType(False, is_type(int)),
         "Mode": PropertyType(False, is_str()),
+        "ApiKeySourceType": PropertyType(False, is_str()),
     }
 
     runtime_attrs = {"rest_api_id": lambda self: ref(self.logical_id)}
@@ -49,7 +52,7 @@ class ApiGatewayStage(Resource):
 
     runtime_attrs = {"stage_name": lambda self: ref(self.logical_id)}
 
-    def update_deployment_ref(self, deployment_logical_id):
+    def update_deployment_ref(self, deployment_logical_id):  # type: ignore[no-untyped-def]
         self.DeploymentId = ref(deployment_logical_id)
 
 
@@ -71,7 +74,7 @@ class ApiGatewayDeployment(Resource):
 
     runtime_attrs = {"deployment_id": lambda self: ref(self.logical_id)}
 
-    def make_auto_deployable(
+    def make_auto_deployable(  # type: ignore[no-untyped-def]
         self, stage, openapi_version=None, swagger=None, domain=None, redeploy_restapi_parameters=None
     ):
         """
@@ -106,9 +109,9 @@ class ApiGatewayDeployment(Resource):
         if function_names and function_names.get(self.logical_id[:-10], None):
             hash_input.append(function_names.get(self.logical_id[:-10], ""))
         data = self._X_HASH_DELIMITER.join(hash_input)
-        generator = logical_id_generator.LogicalIdGenerator(self.logical_id, data)
-        self.logical_id = generator.gen()
-        digest = generator.get_hash(length=40)  # Get the full hash
+        generator = logical_id_generator.LogicalIdGenerator(self.logical_id, data)  # type: ignore[no-untyped-call]
+        self.logical_id = generator.gen()  # type: ignore[no-untyped-call]
+        digest = generator.get_hash(length=40)  # type: ignore[no-untyped-call] # Get the full hash
         self.Description = "RestApi deployment id: {}".format(digest)
         stage.update_deployment_ref(self.logical_id)
 
@@ -116,7 +119,13 @@ class ApiGatewayDeployment(Resource):
 class ApiGatewayResponse(object):
     ResponseParameterProperties = ["Headers", "Paths", "QueryStrings"]
 
-    def __init__(self, api_logical_id=None, response_parameters=None, response_templates=None, status_code=None):
+    def __init__(
+        self,
+        api_logical_id: str,
+        response_parameters: Optional[Dict[str, Any]] = None,
+        response_templates: Optional[Dict[str, Any]] = None,
+        status_code: Optional[str] = None,
+    ) -> None:
         if response_parameters:
             for response_parameter_key in response_parameters.keys():
                 if response_parameter_key not in ApiGatewayResponse.ResponseParameterProperties:
@@ -124,7 +133,7 @@ class ApiGatewayResponse(object):
                         api_logical_id, "Invalid gateway response parameter '{}'".format(response_parameter_key)
                     )
 
-        status_code_str = self._status_code_string(status_code)
+        status_code_str = self._status_code_string(status_code)  # type: ignore[no-untyped-call]
         # status_code must look like a status code, if present. Let's not be judgmental; just check 0-999.
         if status_code and not match(r"^[0-9]{1,3}$", status_code_str):
             raise InvalidResourceException(api_logical_id, "Property 'StatusCode' must be numeric")
@@ -135,10 +144,10 @@ class ApiGatewayResponse(object):
         self.response_templates = response_templates or Py27Dict()
         self.status_code = status_code_str
 
-    def generate_swagger(self):
+    def generate_swagger(self):  # type: ignore[no-untyped-def]
         # Applying Py27Dict here as this goes into swagger
         swagger = Py27Dict()
-        swagger["responseParameters"] = self._add_prefixes(self.response_parameters)
+        swagger["responseParameters"] = self._add_prefixes(self.response_parameters)  # type: ignore[no-untyped-call]
         swagger["responseTemplates"] = self.response_templates
 
         # Prevent "null" being written.
@@ -147,7 +156,7 @@ class ApiGatewayResponse(object):
 
         return swagger
 
-    def _add_prefixes(self, response_parameters):
+    def _add_prefixes(self, response_parameters):  # type: ignore[no-untyped-def]
         GATEWAY_RESPONSE_PREFIX = "gatewayresponse."
         # applying Py27Dict as this is part of swagger
         prefixed_parameters = Py27Dict()
@@ -163,7 +172,7 @@ class ApiGatewayResponse(object):
 
         return prefixed_parameters
 
-    def _status_code_string(self, status_code):
+    def _status_code_string(self, status_code):  # type: ignore[no-untyped-def]
         return None if status_code is None else str(status_code)
 
 
@@ -230,7 +239,7 @@ class ApiGatewayApiKey(Resource):
 class ApiGatewayAuthorizer(object):
     _VALID_FUNCTION_PAYLOAD_TYPES = [None, "TOKEN", "REQUEST"]
 
-    def __init__(
+    def __init__(  # type: ignore[no-untyped-def]
         self,
         api_logical_id=None,
         name=None,
@@ -247,13 +256,13 @@ class ApiGatewayAuthorizer(object):
         if function_payload_type not in ApiGatewayAuthorizer._VALID_FUNCTION_PAYLOAD_TYPES:
             raise InvalidResourceException(
                 api_logical_id,
-                name + " Authorizer has invalid " "'FunctionPayloadType': " + function_payload_type + ".",
+                f"{name} Authorizer has invalid 'FunctionPayloadType': {function_payload_type}.",
             )
 
-        if function_payload_type == "REQUEST" and self._is_missing_identity_source(identity):
+        if function_payload_type == "REQUEST" and self._is_missing_identity_source(identity):  # type: ignore[no-untyped-call]
             raise InvalidResourceException(
                 api_logical_id,
-                name + " Authorizer must specify Identity with at least one "
+                f"{name} Authorizer must specify Identity with at least one "
                 "of Headers, QueryStrings, StageVariables, or Context.",
             )
 
@@ -270,7 +279,7 @@ class ApiGatewayAuthorizer(object):
         self.is_aws_iam_authorizer = is_aws_iam_authorizer
         self.authorization_scopes = authorization_scopes
 
-    def _is_missing_identity_source(self, identity):
+    def _is_missing_identity_source(self, identity):  # type: ignore[no-untyped-def]
         if not identity:
             return True
 
@@ -292,35 +301,35 @@ class ApiGatewayAuthorizer(object):
         # If we can resolve ttl, attempt to see if things are valid
         return ttl_int > 0 and required_properties_missing
 
-    def generate_swagger(self):
-        authorizer_type = self._get_type()
+    def generate_swagger(self):  # type: ignore[no-untyped-def]
+        authorizer_type = self._get_type()  # type: ignore[no-untyped-call]
         APIGATEWAY_AUTHORIZER_KEY = "x-amazon-apigateway-authorizer"
         swagger = Py27Dict()
         swagger["type"] = "apiKey"
-        swagger["name"] = self._get_swagger_header_name()
+        swagger["name"] = self._get_swagger_header_name()  # type: ignore[no-untyped-call]
         swagger["in"] = "header"
-        swagger["x-amazon-apigateway-authtype"] = self._get_swagger_authtype()
+        swagger["x-amazon-apigateway-authtype"] = self._get_swagger_authtype()  # type: ignore[no-untyped-call]
 
         if authorizer_type == "COGNITO_USER_POOLS":
             authorizer_dict = Py27Dict()
-            authorizer_dict["type"] = self._get_swagger_authorizer_type()
-            authorizer_dict["providerARNs"] = self._get_user_pool_arn_array()
+            authorizer_dict["type"] = self._get_swagger_authorizer_type()  # type: ignore[no-untyped-call]
+            authorizer_dict["providerARNs"] = self._get_user_pool_arn_array()  # type: ignore[no-untyped-call]
             swagger[APIGATEWAY_AUTHORIZER_KEY] = authorizer_dict
 
         elif authorizer_type == "LAMBDA":
-            swagger[APIGATEWAY_AUTHORIZER_KEY] = Py27Dict({"type": self._get_swagger_authorizer_type()})
-            partition = ArnGenerator.get_partition_name()
+            swagger[APIGATEWAY_AUTHORIZER_KEY] = Py27Dict({"type": self._get_swagger_authorizer_type()})  # type: ignore[no-untyped-call, no-untyped-call]
+            partition = ArnGenerator.get_partition_name()  # type: ignore[no-untyped-call]
             resource = "lambda:path/2015-03-31/functions/${__FunctionArn__}/invocations"
             authorizer_uri = fnSub(
-                ArnGenerator.generate_arn(
+                ArnGenerator.generate_arn(  # type: ignore[no-untyped-call]
                     partition=partition, service="apigateway", resource=resource, include_account_id=False
                 ),
                 {"__FunctionArn__": self.function_arn},
             )
 
             swagger[APIGATEWAY_AUTHORIZER_KEY]["authorizerUri"] = authorizer_uri
-            reauthorize_every = self._get_reauthorize_every()
-            function_invoke_role = self._get_function_invoke_role()
+            reauthorize_every = self._get_reauthorize_every()  # type: ignore[no-untyped-call]
+            function_invoke_role = self._get_function_invoke_role()  # type: ignore[no-untyped-call]
 
             if reauthorize_every is not None:
                 swagger[APIGATEWAY_AUTHORIZER_KEY]["authorizerResultTtlInSeconds"] = reauthorize_every
@@ -328,40 +337,40 @@ class ApiGatewayAuthorizer(object):
             if function_invoke_role:
                 swagger[APIGATEWAY_AUTHORIZER_KEY]["authorizerCredentials"] = function_invoke_role
 
-            if self._get_function_payload_type() == "REQUEST":
-                identity_source = self._get_identity_source()
+            if self._get_function_payload_type() == "REQUEST":  # type: ignore[no-untyped-call]
+                identity_source = self._get_identity_source()  # type: ignore[no-untyped-call]
                 if identity_source:
-                    swagger[APIGATEWAY_AUTHORIZER_KEY]["identitySource"] = self._get_identity_source()
+                    swagger[APIGATEWAY_AUTHORIZER_KEY]["identitySource"] = self._get_identity_source()  # type: ignore[no-untyped-call]
 
         # Authorizer Validation Expression is only allowed on COGNITO_USER_POOLS and LAMBDA_TOKEN
-        is_lambda_token_authorizer = authorizer_type == "LAMBDA" and self._get_function_payload_type() == "TOKEN"
+        is_lambda_token_authorizer = authorizer_type == "LAMBDA" and self._get_function_payload_type() == "TOKEN"  # type: ignore[no-untyped-call]
 
         if authorizer_type == "COGNITO_USER_POOLS" or is_lambda_token_authorizer:
-            identity_validation_expression = self._get_identity_validation_expression()
+            identity_validation_expression = self._get_identity_validation_expression()  # type: ignore[no-untyped-call]
 
             if identity_validation_expression:
                 swagger[APIGATEWAY_AUTHORIZER_KEY]["identityValidationExpression"] = identity_validation_expression
 
         return swagger
 
-    def _get_identity_validation_expression(self):
+    def _get_identity_validation_expression(self):  # type: ignore[no-untyped-def]
         return self.identity and self.identity.get("ValidationExpression")
 
-    def _build_identity_source_item(self, item_prefix, prop_value):
+    def _build_identity_source_item(self, item_prefix, prop_value):  # type: ignore[no-untyped-def]
         item = item_prefix + prop_value
         if isinstance(prop_value, Py27UniStr):
             item = Py27UniStr(item)
         return item
 
-    def _build_identity_source_item_array(self, prop_key, item_prefix):
+    def _build_identity_source_item_array(self, prop_key, item_prefix):  # type: ignore[no-untyped-def]
         arr = []
         if self.identity.get(prop_key):
             arr = [
-                self._build_identity_source_item(item_prefix, prop_value) for prop_value in self.identity.get(prop_key)
+                self._build_identity_source_item(item_prefix, prop_value) for prop_value in self.identity.get(prop_key)  # type: ignore[no-untyped-call]
             ]
         return arr
 
-    def _get_identity_source(self):
+    def _get_identity_source(self):  # type: ignore[no-untyped-def]
         key_prefix_pairs = [
             ("Headers", "method.request.header."),
             ("QueryStrings", "method.request.querystring."),
@@ -369,9 +378,9 @@ class ApiGatewayAuthorizer(object):
             ("Context", "context."),
         ]
 
-        identity_source_array = reduce(
-            lambda accumulator, key_prefix_pair: accumulator
-            + self._build_identity_source_item_array(key_prefix_pair[0], key_prefix_pair[1]),
+        identity_source_array = reduce(  # type: ignore[var-annotated]
+            lambda accumulator, key_prefix_pair: accumulator  # type: ignore[no-any-return]
+            + self._build_identity_source_item_array(key_prefix_pair[0], key_prefix_pair[1]),  # type: ignore[no-untyped-call]
             key_prefix_pairs,
             [],
         )
@@ -383,19 +392,19 @@ class ApiGatewayAuthorizer(object):
 
         return identity_source
 
-    def _get_user_pool_arn_array(self):
+    def _get_user_pool_arn_array(self):  # type: ignore[no-untyped-def]
         return self.user_pool_arn if isinstance(self.user_pool_arn, list) else [self.user_pool_arn]
 
-    def _get_swagger_header_name(self):
-        authorizer_type = self._get_type()
-        payload_type = self._get_function_payload_type()
+    def _get_swagger_header_name(self):  # type: ignore[no-untyped-def]
+        authorizer_type = self._get_type()  # type: ignore[no-untyped-call]
+        payload_type = self._get_function_payload_type()  # type: ignore[no-untyped-call]
 
         if authorizer_type == "LAMBDA" and payload_type == "REQUEST":
             return "Unused"
 
-        return self._get_identity_header()
+        return self._get_identity_header()  # type: ignore[no-untyped-call]
 
-    def _get_type(self):
+    def _get_type(self):  # type: ignore[no-untyped-def]
         if self.is_aws_iam_authorizer:
             return "AWS_IAM"
 
@@ -404,7 +413,7 @@ class ApiGatewayAuthorizer(object):
 
         return "LAMBDA"
 
-    def _get_identity_header(self):
+    def _get_identity_header(self):  # type: ignore[no-untyped-def]
         if self.identity and not isinstance(self.identity, dict):
             raise InvalidResourceException(
                 self.api_logical_id,
@@ -417,20 +426,20 @@ class ApiGatewayAuthorizer(object):
 
         return self.identity.get("Header")
 
-    def _get_reauthorize_every(self):
+    def _get_reauthorize_every(self):  # type: ignore[no-untyped-def]
         if not self.identity:
             return None
 
         return self.identity.get("ReauthorizeEvery")
 
-    def _get_function_invoke_role(self):
+    def _get_function_invoke_role(self):  # type: ignore[no-untyped-def]
         if not self.function_invoke_role or self.function_invoke_role == "NONE":
             return None
 
         return self.function_invoke_role
 
-    def _get_swagger_authtype(self):
-        authorizer_type = self._get_type()
+    def _get_swagger_authtype(self):  # type: ignore[no-untyped-def]
+        authorizer_type = self._get_type()  # type: ignore[no-untyped-call]
         if authorizer_type == "AWS_IAM":
             return "awsSigv4"
 
@@ -439,16 +448,16 @@ class ApiGatewayAuthorizer(object):
 
         return "custom"
 
-    def _get_function_payload_type(self):
+    def _get_function_payload_type(self):  # type: ignore[no-untyped-def]
         return "TOKEN" if not self.function_payload_type else self.function_payload_type
 
-    def _get_swagger_authorizer_type(self):
-        authorizer_type = self._get_type()
+    def _get_swagger_authorizer_type(self):  # type: ignore[no-untyped-def]
+        authorizer_type = self._get_type()  # type: ignore[no-untyped-call]
 
         if authorizer_type == "COGNITO_USER_POOLS":
             return "cognito_user_pools"
 
-        payload_type = self._get_function_payload_type()
+        payload_type = self._get_function_payload_type()  # type: ignore[no-untyped-call]
 
         if payload_type == "REQUEST":
             return "request"
