@@ -2,7 +2,7 @@ import boto3
 import json
 from botocore.exceptions import ClientError, EndpointConnectionError
 import logging
-from time import sleep, time
+from time import sleep
 import copy
 
 from samtranslator.metrics.method_decorator import cw_timer
@@ -45,7 +45,7 @@ class ServerlessAppPlugin(BasePlugin):
     LOCATION_KEY = "Location"
     TEMPLATE_URL_KEY = "TemplateUrl"
 
-    def __init__(self, sar_client=None, wait_for_template_active_status=False, validate_only=False, parameters=None):
+    def __init__(self, sar_client=None, wait_for_template_active_status=False, validate_only=False, parameters=None):  # type: ignore[no-untyped-def]
         """
         Initialize the plugin.
 
@@ -63,14 +63,15 @@ class ServerlessAppPlugin(BasePlugin):
         self._wait_for_template_active_status = wait_for_template_active_status
         self._validate_only = validate_only
         self._parameters = parameters
+        self._total_wait_time = 0
 
         # make sure the flag combination makes sense
         if self._validate_only is True and self._wait_for_template_active_status is True:
             message = "Cannot set both validate_only and wait_for_template_active_status flags to True."
-            raise InvalidPluginException(ServerlessAppPlugin.__name__, message)
+            raise InvalidPluginException(ServerlessAppPlugin.__name__, message)  # type: ignore[no-untyped-call]
 
-    @cw_timer(prefix=PLUGIN_METRICS_PREFIX)
-    def on_before_transform_template(self, template_dict):
+    @cw_timer(prefix=PLUGIN_METRICS_PREFIX)  # type: ignore[no-untyped-call]
+    def on_before_transform_template(self, template_dict):  # type: ignore[no-untyped-def]
         """
         Hook method that gets called before the SAM template is processed.
         The template has passed the validation and is guaranteed to contain a non-empty "Resources" section.
@@ -82,7 +83,7 @@ class ServerlessAppPlugin(BasePlugin):
         :return: Nothing
         """
         template = SamTemplate(template_dict)
-        intrinsic_resolvers = self._get_intrinsic_resolvers(template_dict.get("Mappings", {}))
+        intrinsic_resolvers = self._get_intrinsic_resolvers(template_dict.get("Mappings", {}))  # type: ignore[no-untyped-call]
 
         service_call = None
         if self._validate_only:
@@ -90,15 +91,15 @@ class ServerlessAppPlugin(BasePlugin):
         else:
             service_call = self._handle_create_cfn_template_request
         for logical_id, app in template.iterate({SamResourceType.Application.value}):
-            if not self._can_process_application(app):
+            if not self._can_process_application(app):  # type: ignore[no-untyped-call]
                 # Handle these cases in the on_before_transform_resource event
                 continue
 
-            app_id = self._replace_value(
+            app_id = self._replace_value(  # type: ignore[no-untyped-call]
                 app.properties[self.LOCATION_KEY], self.APPLICATION_ID_KEY, intrinsic_resolvers
             )
 
-            semver = self._replace_value(
+            semver = self._replace_value(  # type: ignore[no-untyped-call]
                 app.properties[self.LOCATION_KEY], self.SEMANTIC_VERSION_KEY, intrinsic_resolvers
             )
 
@@ -111,36 +112,55 @@ class ServerlessAppPlugin(BasePlugin):
 
             if key not in self._applications:
                 try:
-                    if not RegionConfiguration.is_service_supported("serverlessrepo"):
+                    if not RegionConfiguration.is_service_supported("serverlessrepo"):  # type: ignore[no-untyped-call]
                         raise InvalidResourceException(
                             logical_id, "Serverless Application Repository is not available in this region."
                         )
                     # Lazy initialization of the client- create it when it is needed
                     if not self._sar_client:
                         self._sar_client = boto3.client("serverlessrepo")
-                    service_call(app_id, semver, key, logical_id)
+                    self._make_service_call_with_retry(service_call, app_id, semver, key, logical_id)  # type: ignore[no-untyped-call]
                 except InvalidResourceException as e:
                     # Catch all InvalidResourceExceptions, raise those in the before_resource_transform target.
                     self._applications[key] = e
 
-    def _replace_value(self, input_dict, key, intrinsic_resolvers):
-        value = self._resolve_location_value(input_dict.get(key), intrinsic_resolvers)
+    def _make_service_call_with_retry(self, service_call, app_id, semver, key, logical_id):  # type: ignore[no-untyped-def]
+        call_succeeded = False
+        while self._total_wait_time < self.TEMPLATE_WAIT_TIMEOUT_SECONDS:
+            try:
+                service_call(app_id, semver, key, logical_id)
+            except ClientError as e:
+                error_code = e.response["Error"]["Code"]
+                if error_code == "TooManyRequestsException":
+                    LOG.debug("SAR call timed out for application id {}".format(app_id))
+                    sleep_time = self._get_sleep_time_sec()  # type: ignore[no-untyped-call]
+                    sleep(sleep_time)
+                    self._total_wait_time += sleep_time
+                    continue
+                raise e
+            call_succeeded = True
+            break
+        if not call_succeeded:
+            raise InvalidResourceException(logical_id, "Failed to call SAR, timeout limit exceeded.")
+
+    def _replace_value(self, input_dict, key, intrinsic_resolvers):  # type: ignore[no-untyped-def]
+        value = self._resolve_location_value(input_dict.get(key), intrinsic_resolvers)  # type: ignore[no-untyped-call]
         input_dict[key] = value
         return value
 
-    def _get_intrinsic_resolvers(self, mappings):
+    def _get_intrinsic_resolvers(self, mappings):  # type: ignore[no-untyped-def]
         return [
-            IntrinsicsResolver(self._parameters),
-            IntrinsicsResolver(mappings, {FindInMapAction.intrinsic_name: FindInMapAction()}),
+            IntrinsicsResolver(self._parameters),  # type: ignore[no-untyped-call]
+            IntrinsicsResolver(mappings, {FindInMapAction.intrinsic_name: FindInMapAction()}),  # type: ignore[no-untyped-call, no-untyped-call]
         ]
 
-    def _resolve_location_value(self, value, intrinsic_resolvers):
+    def _resolve_location_value(self, value, intrinsic_resolvers):  # type: ignore[no-untyped-def]
         resolved_value = copy.deepcopy(value)
         for intrinsic_resolver in intrinsic_resolvers:
             resolved_value = intrinsic_resolver.resolve_parameter_refs(resolved_value)
         return resolved_value
 
-    def _can_process_application(self, app):
+    def _can_process_application(self, app):  # type: ignore[no-untyped-def]
         """
         Determines whether or not the on_before_transform_template event can process this application
 
@@ -155,7 +175,7 @@ class ServerlessAppPlugin(BasePlugin):
             and app.properties[self.LOCATION_KEY][self.SEMANTIC_VERSION_KEY] is not None
         )
 
-    def _handle_get_application_request(self, app_id, semver, key, logical_id):
+    def _handle_get_application_request(self, app_id, semver, key, logical_id):  # type: ignore[no-untyped-def]
         """
         Method that handles the get_application API call to the serverless application repo
 
@@ -168,11 +188,8 @@ class ServerlessAppPlugin(BasePlugin):
         :param string logical_id: the logical_id of this application resource
         """
         LOG.info("Getting application {}/{} from serverless application repo...".format(app_id, semver))
-        get_application = lambda app_id, semver: self._sar_client.get_application(
-            ApplicationId=self._sanitize_sar_str_param(app_id), SemanticVersion=self._sanitize_sar_str_param(semver)
-        )
         try:
-            self._sar_service_call(get_application, logical_id, app_id, semver)
+            self._sar_service_call(self._get_application, logical_id, app_id, semver)
             self._applications[key] = {"Available"}
             LOG.info("Finished getting application {}/{}.".format(app_id, semver))
         except EndpointConnectionError as e:
@@ -181,7 +198,7 @@ class ServerlessAppPlugin(BasePlugin):
             LOG.warning(warning_message)
             self._applications[key] = {"Unable to verify"}
 
-    def _handle_create_cfn_template_request(self, app_id, semver, key, logical_id):
+    def _handle_create_cfn_template_request(self, app_id, semver, key, logical_id):  # type: ignore[no-untyped-def]
         """
         Method that handles the create_cloud_formation_template API call to the serverless application repo
 
@@ -191,17 +208,14 @@ class ServerlessAppPlugin(BasePlugin):
         :param string logical_id: the logical_id of this application resource
         """
         LOG.info("Requesting to create CFN template {}/{} in serverless application repo...".format(app_id, semver))
-        create_cfn_template = lambda app_id, semver: self._sar_client.create_cloud_formation_template(
-            ApplicationId=self._sanitize_sar_str_param(app_id), SemanticVersion=self._sanitize_sar_str_param(semver)
-        )
-        response = self._sar_service_call(create_cfn_template, logical_id, app_id, semver)
+        response = self._sar_service_call(self._create_cfn_template, logical_id, app_id, semver)
 
         LOG.info("Requested to create CFN template {}/{} in serverless application repo.".format(app_id, semver))
         self._applications[key] = response[self.TEMPLATE_URL_KEY]
         if response["Status"] != "ACTIVE":
             self._in_progress_templates.append((response[self.APPLICATION_ID_KEY], response["TemplateId"]))
 
-    def _sanitize_sar_str_param(self, param):
+    def _sanitize_sar_str_param(self, param):  # type: ignore[no-untyped-def]
         """
         Sanitize SAR API parameter expected to be a string.
 
@@ -216,8 +230,8 @@ class ServerlessAppPlugin(BasePlugin):
             return None
         return str(param)
 
-    @cw_timer(prefix=PLUGIN_METRICS_PREFIX)
-    def on_before_transform_resource(self, logical_id, resource_type, resource_properties):
+    @cw_timer(prefix=PLUGIN_METRICS_PREFIX)  # type: ignore[no-untyped-call]
+    def on_before_transform_resource(self, logical_id, resource_type, resource_properties):  # type: ignore[no-untyped-def]
         """
         Hook method that gets called before "each" SAM resource gets processed
 
@@ -229,11 +243,11 @@ class ServerlessAppPlugin(BasePlugin):
         :return: Nothing
         """
 
-        if not self._resource_is_supported(resource_type):
+        if not self._resource_is_supported(resource_type):  # type: ignore[no-untyped-call]
             return
 
         # Sanitize properties
-        self._check_for_dictionary_key(logical_id, resource_properties, [self.LOCATION_KEY])
+        self._check_for_dictionary_key(logical_id, resource_properties, [self.LOCATION_KEY])  # type: ignore[no-untyped-call]
 
         # If location isn't a dictionary, don't modify the resource.
         if not isinstance(resource_properties[self.LOCATION_KEY], dict):
@@ -241,7 +255,7 @@ class ServerlessAppPlugin(BasePlugin):
             return
 
         # If it is a dictionary, check for other required parameters
-        self._check_for_dictionary_key(
+        self._check_for_dictionary_key(  # type: ignore[no-untyped-call]
             logical_id, resource_properties[self.LOCATION_KEY], [self.APPLICATION_ID_KEY, self.SEMANTIC_VERSION_KEY]
         )
 
@@ -279,7 +293,7 @@ class ServerlessAppPlugin(BasePlugin):
         if not self._validate_only:
             resource_properties[self.TEMPLATE_URL_KEY] = self._applications[key]
 
-    def _check_for_dictionary_key(self, logical_id, dictionary, keys):
+    def _check_for_dictionary_key(self, logical_id, dictionary, keys):  # type: ignore[no-untyped-def]
         """
         Checks a dictionary to make sure it has a specific key. If it does not, an
         InvalidResourceException is thrown.
@@ -290,12 +304,10 @@ class ServerlessAppPlugin(BasePlugin):
         """
         for key in keys:
             if key not in dictionary:
-                raise InvalidResourceException(
-                    logical_id, "Resource is missing the required [{}] " "property.".format(key)
-                )
+                raise InvalidResourceException(logical_id, f"Resource is missing the required [{key}] property.")
 
-    @cw_timer(prefix=PLUGIN_METRICS_PREFIX)
-    def on_after_transform_template(self, template):
+    @cw_timer(prefix=PLUGIN_METRICS_PREFIX)  # type: ignore[no-untyped-call]
+    def on_after_transform_template(self, template):  # type: ignore[no-untyped-def]
         """
         Hook method that gets called after the template is processed
 
@@ -307,29 +319,25 @@ class ServerlessAppPlugin(BasePlugin):
         if not self._wait_for_template_active_status or self._validate_only:
             return
 
-        start_time = time()
-        while (time() - start_time) < self.TEMPLATE_WAIT_TIMEOUT_SECONDS:
+        while self._total_wait_time < self.TEMPLATE_WAIT_TIMEOUT_SECONDS:
             # Check each resource to make sure it's active
             LOG.info("Checking resources in serverless application repo...")
             idx = 0
             while idx < len(self._in_progress_templates):
                 application_id, template_id = self._in_progress_templates[idx]
-                get_cfn_template = lambda application_id, template_id: self._sar_client.get_cloud_formation_template(
-                    ApplicationId=self._sanitize_sar_str_param(application_id),
-                    TemplateId=self._sanitize_sar_str_param(template_id),
-                )
 
                 try:
-                    response = self._sar_service_call(get_cfn_template, application_id, application_id, template_id)
+                    response = self._sar_service_call(
+                        self._get_cfn_template, application_id, application_id, template_id
+                    )
                 except ClientError as e:
                     error_code = e.response["Error"]["Code"]
                     if error_code == "TooManyRequestsException":
                         LOG.debug("SAR call timed out for application id {}".format(application_id))
                         break  # We were throttled by SAR, break out to a sleep
-                    else:
-                        raise e
+                    raise e
 
-                if self._is_template_active(response, application_id, template_id):
+                if self._is_template_active(response, application_id, template_id):  # type: ignore[no-untyped-call]
                     self._in_progress_templates.remove((application_id, template_id))
                 else:
                     idx += 1  # check next template
@@ -341,19 +349,21 @@ class ServerlessAppPlugin(BasePlugin):
                 break
 
             # Sleep a little so we don't spam service calls
-            sleep(self._get_sleep_time_sec())
+            sleep_time = self._get_sleep_time_sec()  # type: ignore[no-untyped-call]
+            sleep(sleep_time)
+            self._total_wait_time += sleep_time
 
         # Not all templates reached active status
         if len(self._in_progress_templates) != 0:
             application_ids = [items[0] for items in self._in_progress_templates]
             raise InvalidResourceException(
-                application_ids, "Timed out waiting for nested stack templates " "to reach ACTIVE status."
+                application_ids, "Timed out waiting for nested stack templates to reach ACTIVE status."
             )
 
-    def _get_sleep_time_sec(self):
+    def _get_sleep_time_sec(self):  # type: ignore[no-untyped-def]
         return self.SLEEP_TIME_SECONDS
 
-    def _is_template_active(self, response, application_id, template_id):
+    def _is_template_active(self, response, application_id, template_id):  # type: ignore[no-untyped-def]
         """
         Checks the response from a SAR service call; returns True if the template is active,
         throws an exception if the request expired and returns False in all other cases.
@@ -365,15 +375,13 @@ class ServerlessAppPlugin(BasePlugin):
         status = response["Status"]  # options: PREPARING, EXPIRED or ACTIVE
 
         if status == "EXPIRED":
-            message = "Template for {} with id {} returned status: {}. Cannot access an expired " "template.".format(
-                application_id, template_id, status
-            )
+            message = f"Template for {application_id} with id {template_id} returned status: {status}. Cannot access an expired template."
             raise InvalidResourceException(application_id, message)
 
         return status == "ACTIVE"
 
-    @cw_timer(prefix="External", name="SAR")
-    def _sar_service_call(self, service_call_lambda, logical_id, *args):
+    @cw_timer(prefix="External", name="SAR")  # type: ignore[no-untyped-call]
+    def _sar_service_call(self, service_call_lambda, logical_id, *args):  # type: ignore[no-untyped-def]
         """
         Handles service calls and exception management for service calls
         to the Serverless Application Repository.
@@ -391,7 +399,7 @@ class ServerlessAppPlugin(BasePlugin):
                 raise InvalidResourceException(logical_id, e.response["Error"]["Message"])
             raise e
 
-    def _resource_is_supported(self, resource_type):
+    def _resource_is_supported(self, resource_type):  # type: ignore[no-untyped-def]
         """
         Is this resource supported by this plugin?
 
@@ -399,3 +407,19 @@ class ServerlessAppPlugin(BasePlugin):
         :return: True, if this plugin supports this resource. False otherwise
         """
         return resource_type == self.SUPPORTED_RESOURCE_TYPE
+
+    def _get_application(self, app_id, semver):  # type: ignore[no-untyped-def]
+        return self._sar_client.get_application(
+            ApplicationId=self._sanitize_sar_str_param(app_id), SemanticVersion=self._sanitize_sar_str_param(semver)  # type: ignore[no-untyped-call]
+        )
+
+    def _create_cfn_template(self, app_id, semver):  # type: ignore[no-untyped-def]
+        return self._sar_client.create_cloud_formation_template(
+            ApplicationId=self._sanitize_sar_str_param(app_id), SemanticVersion=self._sanitize_sar_str_param(semver)  # type: ignore[no-untyped-call]
+        )
+
+    def _get_cfn_template(self, app_id, template_id):  # type: ignore[no-untyped-def]
+        return self._sar_client.get_cloud_formation_template(
+            ApplicationId=self._sanitize_sar_str_param(app_id),  # type: ignore[no-untyped-call]
+            TemplateId=self._sanitize_sar_str_param(template_id),  # type: ignore[no-untyped-call]
+        )
